summaryrefslogtreecommitdiffstats
path: root/sys/pci/ncr.c
diff options
context:
space:
mode:
authorphk <phk@FreeBSD.org>1996-05-02 14:21:14 +0000
committerphk <phk@FreeBSD.org>1996-05-02 14:21:14 +0000
commit5a6fb3a7da69f11fbe5093f4a2cc7a4d86df5b36 (patch)
treec11aef2f7af5663393e978cd03a223a2ffbe6c69 /sys/pci/ncr.c
parent189514aa416a464e44c25c45746e8ed5e850f03d (diff)
downloadFreeBSD-src-5a6fb3a7da69f11fbe5093f4a2cc7a4d86df5b36.zip
FreeBSD-src-5a6fb3a7da69f11fbe5093f4a2cc7a4d86df5b36.tar.gz
removed:
CLBYTES PD_SHIFT PGSHIFT NBPG PGOFSET CLSIZELOG2 CLSIZE pdei() ptei() kvtopte() ptetov() ispt() ptetoav() &c &c new: NPDEPG Major macro cleanup.
Diffstat (limited to 'sys/pci/ncr.c')
-rw-r--r--sys/pci/ncr.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/sys/pci/ncr.c b/sys/pci/ncr.c
index f9b8257..cebdcb7 100644
--- a/sys/pci/ncr.c
+++ b/sys/pci/ncr.c
@@ -1,6 +1,6 @@
/**************************************************************************
**
-** $Id: ncr.c,v 1.69 1996/03/31 03:17:50 gibbs Exp $
+** $Id: ncr.c,v 1.70 1996/04/07 17:32:33 bde Exp $
**
** Device driver for the NCR 53C810 PCI-SCSI-Controller.
**
@@ -147,10 +147,10 @@
/*
** The maximum transfer length (should be >= 64k).
** MUST NOT be greater than (MAX_SCATTER-1) * NBPG.
*/
-#define MAX_SIZE ((MAX_SCATTER-1) * (long) NBPG)
+#define MAX_SIZE ((MAX_SCATTER-1) * (long) PAGE_SIZE)
/*
** other
@@ -1254,7 +1254,7 @@ static void ncr_attach (pcici_t tag, int unit);
static char ident[] =
- "\n$Id: ncr.c,v 1.69 1996/03/31 03:17:50 gibbs Exp $\n";
+ "\n$Id: ncr.c,v 1.70 1996/04/07 17:32:33 bde Exp $\n";
static u_long ncr_version = NCR_VERSION * 11
+ (u_long) sizeof (struct ncb) * 7
@@ -6425,7 +6425,7 @@ static int ncr_scatter
free = MAX_SCATTER - 1;
- if (vaddr & (NBPG-1)) free -= datalen / NBPG;
+ if (vaddr & (PAGE_SIZE-1)) free -= datalen / PAGE_SIZE;
if (free>1)
while ((chunk * free >= 2 * datalen) && (chunk>=1024))
@@ -6454,7 +6454,7 @@ static int ncr_scatter
/*
** continue this segment
*/
- pnext = (paddr & (~(NBPG - 1))) + NBPG;
+ pnext = (paddr & (~(PAGE_SIZE - 1))) + PAGE_SIZE;
/*
** Compute max size
OpenPOWER on IntegriCloud
@@ -147,10 +147,10 @@
/*
** The maximum transfer length (should be >= 64k).
-** MUST NOT be greater than (MAX_SCATTER-1) * NBPG.
+** MUST NOT be greater than (MAX_SCATTER-1) * PAGE_SIZE.
*/